@@ -58,6 +58,9 @@ new_tab2 <- data.frame(
   age_init = 40:45,
   .weights = runif(6)
 )
-ndt2 <- update(res, newdata = new_tab2)
 
-summary(ndt2)
+#'\dontrun{
+#'ndt2 <- update(res, newdata = new_tab2)
+#'
+#'summary(ndt2)
+#'}
